%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%    TESTING APPROXIMATE SOLUTIONS TO THE CME        %%%%%%%%%%%%
%%%%%%%%%%%             COMPUTE POWER CURVES                   %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 02/25/2013                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

clear all;
close all;

%
% Initialize parameters
%

numMCsamples = 4000;

rVals  = linspace(0.5,1,50);
mu1    = 0.5;
sigma1 = 0.05;
mu2    = 0.8;
sigma2 = 0.02;

%
% Compute power curves
%

alpha = 0.1;
L = 50;
betaL50a05 = findPower(mu1,sigma1,mu2,sigma2,alpha,L,numMCsamples,rVals );

alpha = 0.1;
L = 100;
betaL100a05 = findPower(mu1,sigma1,mu2,sigma2,alpha,L,numMCsamples,rVals );

alpha = 0.01;
L = 50;
betaL50a01 = findPower(mu1,sigma1,mu2,sigma2,alpha,L,numMCsamples,rVals );

alpha = 0.01;
L = 100;
betaL100a01 = findPower(mu1,sigma1,mu2,sigma2,alpha,L,numMCsamples,rVals );

%
% Plot results
%

plot(rVals,betaL50a01,'--g','LineWidth',2);
hold on;
plot(rVals,betaL100a01,'g','LineWidth',2);
plot(rVals,betaL50a05,'--r','LineWidth',2);
plot(rVals,betaL100a05,'r','LineWidth',2);
hold off;
axis([min(rVals) max(rVals) 0 1.05]);
h=legend('\alpha=0.01,L=50',...
         '\alpha=0.01,L=100',...
         '\alpha=0.1,L=50',...
         '\alpha=0.1,L=100',...
         'Location','SouthWest');
set(h,'FontSize',12);
xlabel('r','FontSize',14);ylabel('Statistical Power','FontSize',14)
saveas(gcf,'results/powerCurves.fig')