%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%    TESTING APPROXIMATE SOLUTIONS TO THE CME        %%%%%%%%%%%%
%%%%%%%%%%%             COMPUTE L AND ALPHA                    %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 02/24/2013                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function [L,alpha] = findLalpha(LNAmean,LNAstd,r_1,r_0,b_1,b_0,...
                     mu2star,sigma2Star)
                         
%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

L            = 200;    % initial value of L 
Lstep        = 50;     % step-size to increase L
alphastep    = 0.5;    % multiplicative step size to decrease alpha
alpha        = b_0;    % initialize alpha to b_0
numMCsamples = 4000;   % number of samples used to compute power

beta_a_r(1) = b_0 + 1; % Initialize so conditions are not met
beta_a_r(2) = b_1 - 1; % Initialize so conditions are not met

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Decrease alpha and increase L until the conditions are met
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

while (beta_a_r(1)>b_0) % power too high in acceptance region
    
    alpha    = alphastep*alpha; %decrease alpha
    beta_a_r = findPower(LNAmean,LNAstd,alpha,L,numMCsamples,[r_0,r_1],...
                         mu2star,sigma2Star);
    
    while (beta_a_r(2)<b_1) % power too low in rejection region
        
        L        = L + Lstep; % increase L
        beta_a_r = findPower(LNAmean,LNAstd,alpha,L,numMCsamples,...
                             [r_0,r_1],mu2star,sigma2Star);
        
    end
end