%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%    TESTING APPROXIMATE SOLUTIONS TO THE CME        %%%%%%%%%%%%
%%%%%%%%%%%                GAUSSIAN LEAPING                    %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 03/01/2013                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function XX = GaussLeap(k1,k2,Omega,x0,tf,L,tau)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% INPUT PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

M  =  2;           % number of reactions
N  =  2;           % number of spieces
XX = zeros(L,N);   % Monte Carlo samples

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% MONTE CARLO ITERATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

for iter=1:L
    Z   = zeros(M,1);
    X   = x0;
    for t=tau:tau:tf
        propensity(1)= k1*X(1)*X(2)/Omega;
        propensity(2)= k2*X(2);
        
        propensity(propensity<0) = 0;
       
        Norm   = normrnd(propensity.*tau,sqrt(propensity.*tau));
        Z      = Z + Norm';
        
        X(1) = x0(1)-Z(1);
        X(2) = x0(2)+Z(1)-Z(2);
    end 
    XX(iter,1) = X(1);
    XX(iter,2) = X(2);
end