%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%    TESTING APPROXIMATE SOLUTIONS TO THE CME        %%%%%%%%%%%%
%%%%%%%%%%%        SOLVE SIR MODEL USING IE METHOD             %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 02/27/2013                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize simulation parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

tic;        % start timer

tau = 0.01; % time-step in days  
tf  = 6;    % simulation time in days

display('Running IE Method. Please wait...');

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Initialize model parameters
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

s0 = 762;            % initial number of susceptible individuals
i0 = 1;              % initial number of infected individuals 
r0 = 0;              % initial number of recovered individuals 

M  = 2;              % number of reactions

k1 = 0.00218;        % 1/day,  X_1 + X_2 -> 2X_2
k2 = 0.44036;        % 1/day,        X_2 -> X_3
         
steps = tf/tau;      % number of steps

% determine sample space Z

hyperCubeOrigin = zeros(M,1); % origin of hypercube
hyperCubeExtent = [762;763];  % extent of hypercube
K               = 763*764;    % number of states

% define initial probability 

pPrev    = zeros(K,1);
pPrev(1) = 1;

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Solve system
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

% find implicit Euler matrix
IminusTauA = genMatrix(k1,k2,s0,i0,K,hyperCubeOrigin,hyperCubeExtent,M,tau);

% perform implicit Euler solver steps

for index = 1:steps
    %
    % Do Euler solver steps
    %
    pNext = IminusTauA\pPrev; % matlab automatically performs recursive substitution
    pPrev = pNext;            % prepare for next time step

end

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Map Probability to SI plane
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

SIprobs = mapProbs(pNext,hyperCubeOrigin,hyperCubeExtent,s0,i0);

save('results/SIprobs_groundTruth.mat','SIprobs')