%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%    TESTING APPROXIMATE SOLUTIONS TO THE CME        %%%%%%%%%%%%
%%%%%%%%%%%                EXACT SAMPLING                      %%%%%%%%%%%%
%%%%%%%%%%%          Authors: Jenkinson/Goutsias               %%%%%%%%%%%%
%%%%%%%%%%%           Last Modified: 03/02/2013                %%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

function XX = PoissLeap(k1,k2,Omega,x0,tf,L,tau)

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% INPUT PARAMETERS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

M  =  2;           % number of reactions
N  =  2;           % number of species
XX = zeros(L,N);   % Monte Carlo samples

%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%% MONTE CARLO ITERATIONS
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%

for iter=1:L
    Z   = zeros(M,1);
    X   = x0;
    for t=tau:tau:tf
        propensity(1) = k1*X(1)*X(2)/Omega;
        propensity(2) = k2*X(2);
        
        propensity(propensity<0) = 0;
       
        R    = poissrnd(propensity.*tau);
        Z    = Z + R';
        X(1) = x0(1)-Z(1);
        X(2) = x0(2)+Z(1)-Z(2);
    end 
    XX(iter,1) = X(1);
    XX(iter,2) = X(2);
end